//
//  QDFileRecognizeViewController.m
//  QCloudSDKDemo
//
//  Created by Sword on 2019/8/12.
//  Copyright © 2019 Tencent. All rights reserved.
//

#import "QDFileRecognizeViewController.h"
#import "QDDefine.h"
#import "UIView+Toast.h"

@interface QDFileRecognizeViewController ()<QCloudFileRecognizerDelegate>

@property (nonatomic, strong) QCloudFileRecognizer *recognizer;
@property (weak, nonatomic) IBOutlet UITextView *textView;

@property (nonatomic, strong) NSString *taskId;
@property (nonatomic, strong) NSString *requestId;


@end

@implementation QDFileRecognizeViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.navigationItem.title = @"录音文件识别";
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    NSInteger authorize = [defaults integerForKey:@"authorize"];
    if (authorize) {
        _recognizer = [[QCloudFileRecognizer alloc] initWithAppId:kQDAppId secretId:kQDSecretId secretKey:kQDSecretKey sn:kQDSn deviceId:kQDDeviceId];
    } else {
        _recognizer = [[QCloudFileRecognizer alloc] initWithAppId:kQDAppId secretId:kQDSecretId secretKey:kQDSecretKey];
    }
    _recognizer.delegate = self;
    // Do any additional setup after loading the view.
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    [_recognizer clear];
}
/*
#pragma mark - Navigation

// In a storyboard-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}
*/
- (IBAction)onRecognizeWithUrlButtonTouched:(id)sender
{
    [self.view makeToastActivity:CSToastPositionCenter];
    QCloudFileRecognizeParams *params = [QCloudFileRecognizeParams defaultRequestParams];
    params.audioUrl = @"https://asr-audio-1256237915.cos.ap-shanghai.myqcloud.com/30s.wav";
    [_recognizer recognize:params];
}

- (IBAction)onRecognizeWithDataButtonTouched:(id)sender
{
    [self.view makeToastActivity:CSToastPositionCenter];
    QCloudFileRecognizeParams *params = [QCloudFileRecognizeParams defaultRequestParams];
    NSString *filePath = [[NSBundle mainBundle] pathForResource:@"recordedFile" ofType:@"wav"];
    NSData *audioData = [[NSData alloc] initWithContentsOfFile:filePath];
    params.audioData = audioData;
    params.sourceType = QCloudAudioSourceTypeAudioData;
    [_recognizer recognize:params];
    
}

//[_recognizer clear];调用后，如果有保存上次的id 可以执行这个方法查询结果。正在识别中的不需要调用此方法查询
- (void)getResult {
    if (_recognizer) {
        [_recognizer pollingRecognizeResult:self.taskId clientRequestId:self.requestId];
    }
}

#pragma mark - QCloudFileRecognizerDelegate
- (void)fileRecognizer:(QCloudFileRecognizer *_Nullable)recognizer requestId:(NSInteger)requestId text:(nullable NSString *)text resultData:(nullable NSDictionary *)resultData
{
    NSLog(@"QCloudFileRecognizer requestId:%ld text:%@", requestId, text);
    self.textView.text = text;
    [self.view hideToastActivity];
}

- (void)fileRecognizer:(QCloudFileRecognizer *_Nullable)recognizer requestId:(NSInteger)requestId error:(nullable NSError *)error resultData:(nullable NSDictionary *)resultData
{
    NSLog(@"QCloudFileRecognizer requestId:%ld error:%@", requestId, error);
    self.textView.text = [error localizedDescription];
    [self.view hideToastActivity];
}

/**
 录音文件已成功上传服务器，正在排队识别中
 @param recognizer 录音文件识别器
 @param requestId 请求唯一标识requestId
 @param taskId 向服务器查询识别结果唯一标识
 */
- (void)fileRecognizerDidStart:(QCloudFileRecognizer *_Nullable)recognizer requestId:(NSString *_Nonnull)requestId taskId:(NSString *_Nonnull)taskId {
    
    self.requestId = requestId;
    self.taskId = taskId;
    
}

@end
